<?php
/**
 * Estonian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Oliver S6ro <seem.iges@mail.ee>
 * @author     Aari Juhanson <aari@vmg.vil.ee>
 * @author     Kaiko Kaur <kaiko@kultuur.edu.ee>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Toimeta seda lehte';
$lang['btn_source'] = 'Näita lehepõhja';
$lang['btn_show']   = 'Näita lehte';
$lang['btn_create'] = 'Tekita selle lingi alla leht';
$lang['btn_search'] = 'Otsi';
$lang['btn_save']   = 'Salvesta';
$lang['btn_preview']= 'Eelvaade';
$lang['btn_top']    = 'Tagasi lehe algusesse';
$lang['btn_revs']   = 'Eelmised versioonid';
$lang['btn_recent'] = 'Viimased muudatused';
$lang['btn_upload'] = 'Lae üles';
$lang['btn_cancel'] = 'Katkesta';
$lang['btn_index']  = 'Sisukord';
$lang['btn_secedit']= 'Toimeta';
$lang['btn_login']  = 'Logi sisse';
$lang['btn_logout'] = 'Logi välja';
$lang['btn_admin']  = 'Administreeri';
$lang['btn_update'] = 'Uuenda';
$lang['btn_delete'] = 'Kustuta';

$lang['loggedinas'] = 'Logis sisse kui';
$lang['user']       = 'Kasutaja';
$lang['pass']       = 'Parool';
$lang['remember']   = 'Pea mind meeles';
$lang['fullname']   = 'Täielik nimi';
$lang['email']      = 'E-post';
$lang['register']   = 'Registreeri uus kasutaja';
$lang['badlogin']   = 'Oops, Sinu kasutajanimi või parool oli vale.';

$lang['regmissing'] = 'Kõik väljad tuleb ära täita.';
$lang['reguexists'] = 'Tegelikult on sellise nimega kasutaja juba olemas.';
$lang['regsuccess'] = 'Kasutaja sai tehtud. Parool saadeti Sulle e-posti aadressil.';
$lang['regmailfail']= 'Ilmselt tekkis e-posti teel parooli saatmisel mingi tõrge. Palun suhtle sel teemal 
oma serveri administraatoriga!';
$lang['regbadmail'] = 'Tundub, et Sinu antud e-posti aadress ei toimi - kui Sa arvad, et tegemist on 
ekstitusega, suhtle oma serveri administraatoriga';
$lang['regpwmail']  = 'Sinu DokuWiki parool';
$lang['reghere']    = 'Sul ei olegi veel kasutajakontot? No aga tekita see siis endale!';

$lang['txt_upload']   = 'Vali fail, mida üles laadida';
$lang['txt_filename'] = 'Siseta oma Wikinimi (soovituslik)';
$lang['lockedby']     = 'Praegu on selle lukustanud';
$lang['lockexpire']   = 'Lukustus aegub';
$lang['willexpire']   = 'Teie lukustus selle lehe toimetamisele aegub umbes minuti pärast.\nIgasugu  probleemide vältimiseks kasuta eelvaate nuppu, et lukustusarvesti taas tööle panna.';

$lang['notsavedyet'] = 'Sul on seal salvestamata muudatusi, mis kohe kõige kaduva teed lähevad.\nKas Sa ikka tahad edasi liikuda?'; 
$lang['rssfailed']   = 'Sinu soovitud info ammutamisel tekkis viga: ';
$lang['nothingfound']= 'Oops, aga mitte muhvigi ei leitud.';

$lang['mediaselect'] = 'Hunnik faile';
$lang['fileupload']  = 'Faili üleslaadimine';
$lang['uploadsucc']  = 'Üleslaadimine läks ootuspäraselt hästi';
$lang['uploadfail']  = 'Üleslaadimine läks nässu. Äkki pole Sa selleks lihtsalt piisavalt võimukas tegija?'; 
$lang['uploadwrong'] = 'Ei saa Sa midagi üles laadida. Oops, aga seda tüüpi faili sul lihtsalt ei lubata üles laadida';
$lang['namespaces']  = 'Alajaotus';
$lang['mediafiles']  = 'Failid on Sulle kättesaadavad';

$lang['hits']       = 'Päringu tabamused';
$lang['quickhits']  = 'Päringule vastavad lehed';
$lang['toc']        = 'Sisujuht';
$lang['current']    = 'Hetkel kehtiv';
$lang['yours']      = 'Sinu versioon';
$lang['diff']       = 'Näita erinevusi hetkel kehtiva versiooniga';
$lang['line']       = 'Joon';
$lang['breadcrumb'] = 'Käidud rada';
$lang['lastmod']    = 'Viimati muutnud';
$lang['by']         = 'persoon';
$lang['deleted']    = 'eemaldatud';
$lang['created']    = 'tekitatud';
$lang['restored']   = 'vana versioon taastatud';
$lang['summary']    = 'kokkuvõte muudatustest';

$lang['mail_newpage'] = 'leht lisatud:';
$lang['mail_changed'] = 'leht muudetud';

$lang['nosmblinks'] = 'Windowsis võrguarvutiga ühendamine toimib ainult Internet Exploreris ja 
sisevõrgus.\nAga Sa saad õnneks omale lingi kopeerida ja hiljem kuhugi kleepida.';

$lang['qb_alert']   = 'Sisesta palun tekst, mida Sa tahad kujundada.\nSee lisatakse dokumendi lõppu..'; 
$lang['qb_bold']    = 'Rasvane kiri';
$lang['qb_italic']  = 'Kaldkiri';
$lang['qb_underl']  = 'Alajoonega kiri';
$lang['qb_code']    = 'Koodi tekst';
$lang['qb_h1']      = '1. astme pealkiri';
$lang['qb_h2']      = '2. astme pealkiri';
$lang['qb_h3']      = '3. astme pealkiri';
$lang['qb_h4']      = '4. astme pealkiri';
$lang['qb_h5']      = '5. astme pealkiri';
$lang['qb_link']    = 'Siselink';
$lang['qb_extlink'] = 'Välislink';
$lang['qb_hr']      = 'Horisontaalne vahejoon';
$lang['qb_ol']      = 'Nummerdatud nimikiri';
$lang['qb_ul']      = 'Mummuga nimekiri';
$lang['qb_media']   = 'Lisa pilte ja muid faile';
$lang['qb_sig']     = 'Lisa allkiri!';


$lang['del_confirm']= 'Kas kustutame selle kirje?';


//Setup VIM: ex: et ts=2 enc=utf-8 :
